@@ -68,8 +68,11 @@ class Query(ResourceBase):
     def tags(self, *args):
         return self.prop("tags", *args)
 
-    def id(self):
-        return self.prop("id")
+    # def id(self):
+    #     return self.prop("id")
+
+    def id(self, *args):
+        return self.prop("id", *args)
 
     def stat(self):
         self.get()
@@ -142,7 +145,11 @@ class Query(ResourceBase):
                     result = ws.recv()
                     # convert string object to json(array)
                     # todo convert by header type
-                    record = json.loads(result)
+                    try:
+                        record = json.loads(result)
+                    except Exception as e:
+                        self._logger.warning(f"cannot load result from ws {result} {e}")
+                        continue
 
                     for index, col in enumerate(self.header()):
                         if col["type"].startswith(Type.Tuple.value):
@@ -155,8 +162,9 @@ class Query(ResourceBase):
 
                     observer.on_next(record)
                 observer.on_complete()
-            except Exception:
-                pass
+            except Exception as e:
+                self._logger.error("failed to recieve data from websocket", e)
+                observer.on_error(e)
 
         return __query_op
 
